@@ -34,7 +34,7 @@ Google material colors L<http://www.google.com/design/spec/style/color.html>
 =cut
 
 package WebColors ;
-$WebColors::VERSION = '0.4.3';
+$WebColors::VERSION = '0.4.4';
 use 5.0.4 ;
 use warnings ;
 use strict ;
@@ -506,6 +506,7 @@ my %web_colors = (
     bluegrey900 => [ 0x26, 0x32, 0x38 ],
 
     # open colors https://yeun.github.io/open-color/
+    # variations in names handled in colorname_to_rgb
     'oc-gray-0'   => [ 0xf8, 0xf9, 0xfa ],
     'oc-gray-1'   => [ 0xf1, 0xf3, 0xf5 ],
     'oc-gray-2'   => [ 0xe9, 0xec, 0xef ],
@@ -724,9 +725,11 @@ get the rgb values 0..255 to match a color
     my ($r, $g, $b) = colorname_to_rgb( 'goldenrod') ;
 
     # get a material color
-
     ($r, $g, $b) = colorname_to_rgb( 'bluegrey500') ;
 
+    # open colors
+    ($r, $g, $b) = colorname_to_rgb( 'oc-lime-5') ;
+
 entries will be null if there is no match
 
 =cut
@@ -735,8 +738,15 @@ sub colorname_to_rgb
 {
     my ($name) = @_ ;
 
+    $name = lc($name) ;
+
+    # allow variations on open color names
+    $name =~ s/^oc(\w+)(\d)$/oc-$1-$2/ ;
+    $name =~ s/^oc(\w+)-(\d)$/oc-$1-$2/ ;
+    $name =~ s/^oc-(\w+)(\d)$/oc-$1-$2/ ;
+
     # deref the arraryref
-    my $rgb = $web_colors{ lc($name) } ;
+    my $rgb = $web_colors{ $name } ;
 
     $rgb = [ undef, undef, undef ] if ( !$rgb ) ;
     return @$rgb ;
@@ -751,7 +761,6 @@ get the color value as a hex triplet '12ffee' to match a color
     my $hex => colorname_to_hex( 'darkslategray') ;
 
     # get a material color, accented red
-
     $hex => colorname_to_hex( 'reda300') ;
 
 entries will be null if there is no match
